<?php
/**
* © Copyright 2008 IntraHealth International, Inc.
*
* This File is part of I2CE
*
* I2CE is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  Ngorongoro_Module_Trainng
* @package I2CE
* @subpackage Core
* @author Ally Shaban <allyshaban5@gmail.com>
* @copyright Copyright &copy; 2008 IntraHealth International, Inc.
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under
* the terms of the GNU General Public License as published by the Free Software Foundation; either
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class Ngorongoro_Module_Performance extends I2CE_Module{

    public static function getMethods() {
        return array(
            'iHRIS_PageView->action_performance_targets' => 'action_performance_targets'
            );
    }

    public function action_performance_targets($page) {
      if (!$page instanceof iHRIS_PageView) {
          return false;
      }
      $template = $page->getTemplate();
      $appendNode = $template->getElementById('performance_targets');
      if (!$appendNode instanceof DOMNode) {
          return true;
      }
      $person = $page->getPerson();
      if (!$person instanceof iHRIS_Person) {
          return false;
      }
      $factory = I2CE_FormFactory::instance();
      $targetIds = $this->getTargets($person);
      $peformanceTargets = array();
      foreach ($targetIds as $targetId) {
          $targetForm = $factory->createContainer('performance_targets'.'|'.$targetId);
          if (!$targetForm instanceof Ngorongoro_PerformanceTargets) {
              continue;
          }
          $targetForm->populate();
          $peformanceTargets[] = $targetForm;
      }
      if (count($peformanceTargets) == 0) {
          return true;
      }
      foreach ($peformanceTargets as $child) {
          $node = $template->appendFileByNode('view_performance_targets.html', 'div',  $appendNode );
          if (!$node instanceof DOMNode) {
              I2CE::raiseError("Could not find template $template for child form $form of person");
              return false;
          }
          $template->setForm($child,$node);
          //display all productivity reviews
          $child->populateChildren('productivity_review',array('productivity_review'=>'-review_month'));
          $prod_reviews = $child->getChildren('productivity_review');
          if (count($prod_reviews) > 0) {
              $template->setDisplayDataImmediate('has_productivity_review',1,$node);
              $month = date("month");
              $counter = 0;
              foreach ($prod_reviews as $key=>$prod_review) {
                $counter++;
                //displaying 6 productivity reviews only
                if($counter>6)
                continue;
                  if (!  ($reviewNode = $template->appendFileById('view_productivity_review.html','tbody','productivity_review',false,$node)) instanceof DOMNode) {
                      continue;
                  }
                  $template->setForm($prod_review,$reviewNode);
              }
          } else {
              $template->setDisplayDataImmediate('has_productivity_review',0,$node);
          }

          //display all performance reviews
          $child->populateChildren('performance_review');
          $perf_reviews = $child->getChildren('performance_review');
          if (count($perf_reviews) > 0) {
              $template->setDisplayDataImmediate('has_performance_review',1,$node);
              foreach ($perf_reviews as $perf_review) {
                  if (!  ($reviewNode = $template->appendFileById('view_performance_review.html','tbody','performance_review',false,$node)) instanceof DOMNode) {
                      continue;
                  }
                  $template->setForm($perf_review,$reviewNode);
              }
          } else {
              $template->setDisplayDataImmediate('has_performance_review',0,$node);
          }




      }

      return true;
    }

    public function getTargets($personForm) {
      if (!$personForm instanceof iHRIS_Person || $personForm->getId() == '0') {
          return array();
      }
      $year = date("Y");
      $month = date("m");
      if($month >= 7) {
        $period = "July ".$year."/"."June ".($year+1);
      }
      else if($month < 7) {
        $period = "July ".($year-1)."/"."June ".$year;
      }
      $where = array("operator"=>"FIELD_LIMIT",
                      "field"=>"period",
                      "style"=>"equals",
                      "data"=>array("value"=>$period)
                    );
      return $personForm->getChildIds('performance_targets','-date_added',$where); //get all targets.
    }

  static function load_opras_config() {
    $factory = I2CE_FormFactory::instance();
    $srch_oprasConfig = I2CE_FormStorage::search("opras_configuration");
    $opras_config = array();
    if(count($srch_oprasConfig)>0) {
      $opras_config = "opras_configuration|".current($srch_oprasConfig);
      $oprasConfigObj = $factory->createContainer($opras_config);
      $oprasConfigObj->populate();
      $opras_config = array("max_targets"=>$oprasConfigObj->getField("max_targets")->getValue(),
                            "min_targets"=>$oprasConfigObj->getField("min_targets")->getValue(),
                            "target_define_start_date"=>$oprasConfigObj->getField("target_define_start_date")->getDBValue(),
                            "target_define_end_date"=>$oprasConfigObj->getField("target_define_end_date")->getDBValue(),
                            "mid_review_start_date"=>$oprasConfigObj->getField("mid_review_start_date")->getDBValue(),
                            "mid_review_end_date"=>$oprasConfigObj->getField("mid_review_end_date")->getDBValue(),
                            "annual_review_start_date"=>$oprasConfigObj->getField("annual_review_start_date")->getDBValue(),
                            "annual_review_end_date"=>$oprasConfigObj->getField("annual_review_end_date")->getDBValue()
                            );
    }
    return $opras_config;
  }

  static function is_open($open_date,$close_date) {
    $month = date("n");
    $year = date("Y");
    $day = date("j");
    $open_date = explode("-",$open_date);
    $open_month = $open_date[1];
    $open_day = $open_date[2];
    $close_date = explode("-",$close_date);
    $close_month = $close_date[1];
    $close_day = $close_date[2];
    if($open_month<=$close_month) {
      if($month>=$open_month && $month<=$close_month && $day >= $open_day && $day <= $close_day) {
        return true;
      }
      return false;
    }
    else if($open_date>$close_date) {
      if($month < 7 && $month <= $close_month && $day <= $close_day) {
        return true;
      }
      else if($month >= 7 && $month >= $open_month && $day >= $open_day) {
        return true;
      }
      return false;
    }
  }
}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
