<?php
/**
* © Copyright 2007 IntraHealth International, Inc.
*
* This File is part of I2CE
*
* I2CE is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_PageFormPerson
* @package I2CE
* @subpackage Core
* @author Ally Shaban <allyshaban5@gmail.com>
* @copyright Copyright &copy; 2007 IntraHealth International, Inc.
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under
* the terms of the GNU General Public License as published by the Free Software Foundation; either
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class Ngorongoro_PageFormPerformanceReview extends I2CE_PageForm{
    /**
     * Create and load data for the objects used for this form.
     *
     * Create the list object and if this is a form submission load
     * the data from the form data.
     */
     protected function loadObjects() {
         $this->opras_config = Ngorongoro_Module_Performance::load_opras_config();
         if(count($this->opras_config) == 0) {
           $this->userMessage("OPRAS Configuration was not found");
           I2CE::raiseError("OPRAS Configuration was not found");
           return false;
         }
         //check if this is midyear
         $isMidyear = Ngorongoro_Module_Performance::is_open(
                                                              $this->opras_config["mid_review_start_date"],
                                                              $this->opras_config["mid_review_end_date"]
                                                            );
         if(!$isMidyear) {
           //check if this is annual review
           $isAnnual = Ngorongoro_Module_Performance::is_open(
                                                                $this->opras_config["annual_review_start_date"],
                                                                $this->opras_config["annual_review_end_date"]
                                                              );
         }

         if(!$isMidyear && !$isAnnual) {
           $this->userMessage("Performance review is currently closed");
           I2CE::raiseError("Performance review is currently closed");
           return false;
         }

         //make sure we have valid objects
         $ff = I2CE_FormFactory::instance();
         if ($this->isPost()) {
             if ($this->request_exists('id') && $this->request('id')) {
                 if ( ! ($primary = $this->factory->createContainer($this->request('id'))) instanceof Ngorongoro_PerformanceReview) {
                     return false;
                 }
                 $primary->populate();
                 $primary->load($this->post);
             } else {
                 if ( ! ($primary = $this->factory->createContainer('performance_review')) instanceof Ngorongoro_PerformanceReview) {
                     return false;
                 }
                 $primary->load($this->post);
             }
             if (($primary->getParent() == '0' || $primary->getParent() == '' || $primary->getParent() == '|')  && $this->request('parent')) {
                 $primary->setParent($this->request('parent'));
             }
         } elseif ( $this->get_exists('id') ) {
             if ($this->get_exists('id')) {
                 $id = $this->get('id');
                 if (strpos($id,'|')=== false) {
                     I2CE::raiseError("Deprecated use of id variable");
                     $id =  'performance_review|' . $id;
                 }
             } else {
                 $id = 'performance_review|0';
             }
             $primary = $this->factory->createContainer($id);
             if (!$primary instanceof Ngorongoro_PerformanceReview) {
                 I2CE::raiseError("Could not create valid performance_review from id:$id");
                 return false;
             }
             $primary->populate();
         } elseif ( $this->get_exists('parent') ) {
             $primary = $this->factory->createContainer('performance_review|0');
             if (!$primary instanceof Ngorongoro_PerformanceReview) {
                 return false;
             }
             $parent = $this->get('parent');
             if (strpos($parent,'|')=== false) {
                 I2CE::raiseError("Deprecated use of parent variable");
                 $parent =  'performance_targets|' . $id;
             }
             $primary->setParent($parent);
         }
         if ($this->isGet()) {
             $primary->load($this->get());
         }
         if (! ($personTargets = $ff->createContainer( $primary->getParent() ))  instanceof Ngorongoro_PerformanceTargets) {
             I2CE::raiseError("Cannot instantitatne person performance targets " . $primary->getParent());
             return false;
         }
         $this->template->setDisplayData('parent',$personTargets->getNameId());
         $personTargets->populate();
         if (! ($person = $ff->createContainer($personTargets->getParent())) instanceof iHRIS_Person) {
             I2CE::raiseError("bad performance target " . $personTargets->getParent());
             return false;
         }
         $person->populate();
         if ($personTargets->getId() == '0') {
             I2CE::raiseError("Bad ID");
             return false;
         }
         $user = $this->check_user("person|".$person->getId());
         if($user != "employee" & $user != "supervisor") {
           $this->userMessage("Only Supervisor or Staff are allowed to review targets");
           $this->setRedirect(  "view?id=" . $personTargets->getParent() );
           return;
         }
         if($user == "employee") {
           $primary->getField("performance_reviewer")->setFromDB("performance_reviewer|employee");
         }
         else if($user == "supervisor") {
           $primary->getField("performance_reviewer")->setFromDB("performance_reviewer|supervisor");
         }

         if($isMidyear) {
           $primary->getField("review_period")->setFromDB("review_period|mid_year");
         }
         else if($isAnnual) {
           $primary->getField("review_period")->setFromDB("review_period|annual");
         }
         $this->personPerformanceTargets = $personTargets;
         $this->person = $person;

         $this->setObject($primary);
     }

     protected $person;
     protected $personPerformanceTargets;

     /**
      * Set the I2CE_Form object in the page template.
      *
      * This method will pass the edit object to the page template so that it can process all the form variables.
      */
     protected function setForm() {
         $this->template->setForm($this->personPerformanceTargets); //needs to be first for return button
         $this->template->setForm($this->person);
         parent::setForm();
     }

     public function check_user($reviewed_person) {
       $ff = I2CE_FormFactory::instance();
       $username=$this->getUser()->username;
       $where = array("operator"=>"FIELD_LIMIT",
                      "field"=>"username",
                      "style"=>"equals",
                      "data"=>array("value"=>"user|".$username)
                    );
        $user_map = I2CE_FormStorage::listFields("user_map",array("parent"),false,$where);
        if(count($user_map) == 0) {
          return;
        }
        else if(count($user_map) == 1) {
          $parent = current($user_map);
          $user_person_id = $parent["parent"];
          if($user_person_id == $reviewed_person) {
            return "employee";
          }
          //check if this is the supervisor
          else {
            //get person_position object of the person being reviewed
            $reviewedPersObj = $ff->createContainer($reviewed_person);
            $reviewedPersObj->populateChildren("person_position");
            if(count($reviewedPersObj) == 0)
            return ;
            foreach($reviewedPersObj->getChildren("person_position") as $reviewedPersPosObj) {
              $end_date = $reviewedPersPosObj->getField("end_date")->getDisplayValue();
              if($end_date != "")
              continue;
              //getting position of the person being reviewed
              $position = $reviewedPersPosObj->getField("position")->getDBValue();
              $posObj = $ff->createContainer($position);
              if(!$posObj instanceof iHRIS_Position) {
                I2CE::raiseError("$position Not instance of iHRIS_Position");
                return;
              }
              $posObj->populate();
              //getting supervisor position of the person being reviewed
              $supervisorPos = $posObj->getField("supervisor")->getDBValue();
              //serching supervisor person position
              $where = array( 'operator'=>'AND',
                              'operand'=>array(
                                                0=>array(
                                                    'operator'=>'FIELD_LIMIT',
                                                    'field'=>'position',
                                                    'style'=>'equals',
                                                    'data'=>array(
                                                        'value'=>$supervisorPos
                                                        )
                                                    ),
                                                1=>array(
                                                    'operator'=>'FIELD_LIMIT',
                                                    'field'=>'end_date',
                                                    'style'=>'null',
                                                    'data'=>array()
                                                    ),
                                             )
                            );
              $search_pers_pos = I2CE_FormStorage::search("person_position",false,$where);
              if(count($search_pers_pos) == 0)
              return;
              //getting person id of the supervisor
              $supPersPos = "person_position|".$search_pers_pos[0];
              $supPersPosObj = $ff->createContainer($supPersPos);
              if(!$supPersPosObj instanceof iHRIS_PersonPosition) {
                I2CE::raiseError("$supPersPos Not instance of iHRIS_PersonPosition");
                return;
              }
              $supPersPosObj->populate();
              $supervisor_pers_id = $supPersPosObj->getField("parent")->getDBValue();
              //if the supervisor person id differs person id of the current user then return empty
              if($supervisor_pers_id != $user_person_id) {
                return;
              }
              //otherwise this is the supervisor
              else {
                return "supervisor";
              }
            }
          }
        }
     }

    /**
     * Save the objects to the database.
     *
     * Save the default object being edited and return to the view page.
     * @global array
     */
    protected function save() {
        $performance_targets = $this->factory->createContainer("performance_targets");
        $performance_targets->load($this->post);
        parent::save();
        $this->userMessage("Target Saved Successfully");
        $this->setRedirect(  "view?id=" . $performance_targets->getParent() );
        $performance_targets->cleanup();
    }


}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
