<?php
/**
* © Copyright 2007 IntraHealth International, Inc.
*
* This File is part of I2CE
*
* I2CE is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_PageFormPerson
* @package I2CE
* @subpackage Core
* @author Ally Shaban <allyshaban55@gmail.com>
* @copyright Copyright &copy; 2007 IntraHealth International, Inc.
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under
* the terms of the GNU General Public License as published by the Free Software Foundation; either
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class Ngorongoro_PageFormPerformanceTargets extends iHRIS_PageFormParentPerson{



    /**
     * Create and load data for the objects used for this form.
     *
     * Create the list object and if this is a form submission load
     * the data from the form data.
     */
    protected function loadObjects() {
        $this->opras_config = Ngorongoro_Module_Performance::load_opras_config();
        if(count($this->opras_config) == 0) {
          $this->userMessage("OPRAS Configuration was not found");
          I2CE::raiseError("OPRAS Configuration was not found");
          return false;
        }

        //make sure target definition time is open
        $isOpen = Ngorongoro_Module_Performance::is_open(
                                                          $this->opras_config["target_define_start_date"],
                                                          $this->opras_config["target_define_end_date"]
                                                        );
        if(!$isOpen) {
          $this->userMessage("Performance Target definition is closed");
          I2CE::raiseError("Performance Target definition is closed");
          return false;
        }

        $this->factory = I2CE_FormFactory::instance();
        if ($this->isPost()) {
          $primary = $this->factory->createContainer($this->getForm());
          if (!$primary instanceof I2CE_Form) {
              I2CE::raiseError("Could not create performance_targets form");
              return;
          }
          $primary->load($this->post);
        }
        else if ($this->get_exists('id')) {
          $id = $this->get('id');
          if ($this->get_exists('id')) {
              $id = $this->get('id');
              if (strpos($id,'|')=== false) {
                  I2CE::raiseError("Deprecated use of id variable");
                  $id = $this->getForm() . '|' . $id;
              }
          } else {
              $id = $this->getForm() . '|0';
          }
          $primary = $this->factory->createContainer($id);
          if (!$primary instanceof I2CE_Form || $primary->getName() != $this->getForm()) {
              I2CE::raiseError("Could not create valid " . $this->getForm() . "form from id:$id");
              return false;
          }
          $primary->populate();
        }
        elseif ( $this->get_exists('parent') ) {
          $primary = $this->factory->createContainer($this->getForm());
          if (!$primary instanceof I2CE_Form) {
              return;
          }
          $parent = $this->get('parent');
          if (strpos($parent,'|')=== false) {
              I2CE::raiseError("Deprecated use of parent variable");
              $parent =  'person|' . $parent;
          }
          $primary->setParent($parent);
        }
        if ($this->isGet()) {
            $primary->load($this->get());
        }
        $person = parent::loadPerson(  $primary->getParent() );

        $year = date("Y");
        $month = date("m");
        if($month >= 7) {
          $period = "July ".$year."/"."June ".($year+1);
        }
        else if($month < 7) {
          $period = "July ".($year-1)."/"."June ".$year;
        }
        $primary->getField("period")->setValue($period);

        //enusere targets doesnt exceed 8
        $this->ensure_max_targets($period,$person);
        $this->setObject( $person, I2CE_PageForm::EDIT_PARENT);
        $this->setObject( $primary, I2CE_PageForm::EDIT_PRIMARY);
    }

    public function ensure_max_targets($period,$personForm) {
      $where = array("operator"=>"FIELD_LIMIT",
                      "field"=>"period",
                      "style"=>"equals",
                      "data"=>array("value"=>$period)
                    );
      $total_targets = count($personForm->getChildIds('performance_targets',false,$where));
      if($total_targets == $this->opras_config["max_targets"]) {
        $this->userMessage("You have reached a maximum of ".$total_targets." Targets");
        I2CE::raiseError("You have reached a maximum of ".$total_targets." Targets");
        $this->setRedirect("view?id=person|" .$personForm->getId());
      }
    }


    /**
     * Save the objects to the database.
     *
     * Save the default object being edited and return to the view page.
     * @global array
     */
    protected function save() {
        $performance_targets = $this->factory->createContainer("performance_targets");
        $performance_targets->load($this->post);
        parent::save();
        $this->userMessage("Target Saved Successfully");
        $this->setRedirect(  "view?id=" . $performance_targets->getParent() );
        $performance_targets->cleanup();
    }


}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
